export const ACTION_TYPE = Object.freeze({
    CREATE_MANUAL_BLACKLIST: 'create_manual_blacklist',
    CANCEL_MANUAL_BLACKLIST: 'cancel_manual_blacklist',
    CANCEL_AUTOMATIC_BLACKLIST_CLOSE: 'cancel_automatic_blacklist_close',
    CANCEL_AUTOMATIC_BLACKLIST_DONT_CLOSE: 'cancel_automatic_blacklist_dont_close',
})

export const AUCTION_ACCESS_TOKEN = 'auction_token'

export const DATE_RANGE = Object.freeze({
    CURRENT_DAY: 'current_day',
    PAST_DAY: 'past_day',
    CURRENT_WEEK: 'current_week',
    PAST_WEEK: 'past_week',
    CURRENT_MONTH: 'current_month',
    PAST_MONTH: 'past_month',
    PAST_6_MONTHS: 'past_6_months',
})

export const AUCTION_STATUS = Object.freeze({
    PENDING_PAYMENT: 'pending_payment',
    PENDING_REGISTRATION: 'pending_registration',
    PENDING_PENALTY: 'pending_penalty',
    PAID_PENALTY: 'paid_penalty',
    NOT_REGISTERED: 'not_registered',
    REGISTERED: 'registered',
    FINISHED_NOT_PAID: 'finished_not_paid',
    FINISHED_SUCCESS: 'finished_success',
    FINISHED_NOT_TAKEN: 'finished_not_taken',
})

export const AUCTION_ROUND_INFOS = Object.freeze({
    BUTTON_RESUME: 'BUTTON_RESUME',
    BUTTON_STOP: 'BUTTON_STOP',
    AUCTION_PHASE_COMMON: 'AUCTION_PHASE_COMMON',
    AUCTION_PHASE_HIGHLIGHTED: 'AUCTION_PHASE_HIGHLIGHTED',
    ROUND: 'ROUND',
    ROUND_TITLE: 'ROUND_TITLE',
    AT_AUCTION_SINCE: 'AT_AUCTION_SINCE',
    BIDDING_START: 'BIDDING_START',
    BIDDING_END: 'BIDDING_END',
    PENDING_REGULAR_PAYMENT_SINCE: 'PENDING_REGULAR_PAYMENT_SINCE',
    PENDING_PENALTY_PAYMENT_SINCE: 'PENDING_PENALTY_PAYMENT_SINCE',
    PENDING_REGULAR_PAYMENT_BY: 'PENDING_REGULAR_PAYMENT_BY',
    PAID_SINCE: 'PAID_SINCE',
    PENDING_REGISTRATION_BY: 'PENDING_REGISTRATION_BY',
    NOT_REGISTERED_SINCE: 'NOT_REGISTERED_SINCE',
    REGISTERED_SINCE: 'REGISTERED_SINCE',
    STOPPED_SINCE: 'STOPPED_SINCE',
    AUCTION_PHASE_USER_COMMON: 'AUCTION_PHASE_USER_COMMON',
    AUCTION_PHASE_USER_HIGHLIGHTED: 'AUCTION_PHASE_USER_HIGHLIGHTED',
    CURRENT_PRICE: 'CURRENT_PRICE',
    AUCTION_PRICE: 'AUCTION_PRICE',
    PENALTY_AMOUNT: 'PENALTY_AMOUNT',
    VARIABLE_SYMBOL: 'VARIABLE_SYMBOL',
    PENALTY_VARIABLE_SYMBOL: 'PENALTY_VARIABLE_SYMBOL',
    NUMBER_OF_BIDS: 'NUMBER_OF_BIDS',
    NUMBER_OF_BIDDERS: 'NUMBER_OF_BIDDERS',
    WINNER: 'WINNER',
    PENALIZED: 'PENALIZED',
})

/**
 * The definition of the visibility of every piece of information shown on the auction detail's page. Determines
 * displayed information based on the auction round's state. Applies for the latest round.
 * Syntax: `LATEST_ROUND_INFO_VISIBILITY[<round's state>][AUCTION_ROUND_INFOS.<information key>]`, where `true` means
 * the specified information is displayed, `false` it isn't.
 */
export const LATEST_ROUND_INFO_VISIBILITY = Object.freeze({
    NEW: {
        BUTTON_RESUME: false,
        BUTTON_STOP: true,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: false,
        NUMBER_OF_BIDDERS: false,
        WINNER: false,
        PENALIZED: false,
    },
    IN_AUCTION: {
        BUTTON_RESUME: false,
        BUTTON_STOP: true,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: true,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: false,
        PENALIZED: false,
    },
    PENDING_PAYMENT: {
        BUTTON_RESUME: false,
        BUTTON_STOP: true,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: true,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: true,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    PENDING_REGISTRATION: {
        BUTTON_RESUME: false,
        BUTTON_STOP: true,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: true,
        PENDING_REGISTRATION_BY: true,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: true,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    FINISHED_NO_BID: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: false,
        NUMBER_OF_BIDDERS: false,
        WINNER: false,
        PENALIZED: false,
    },
    FINISHED_NOT_PAID: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: true,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: true,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: true,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    FINISHED_NOT_TAKEN: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: true,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: true,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: true,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    FINISHED_SUCCESS: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: true,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: true,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: true,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: true,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    PENDING_PENALTY: {
        BUTTON_RESUME: false,
        BUTTON_STOP: true,
        AUCTION_PHASE_COMMON: false,
        AUCTION_PHASE_HIGHLIGHTED: true,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: true,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: true,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: true,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: false,
        PENALIZED: true,
    },
    STOPPED: {
        BUTTON_RESUME: true,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: false,
        AUCTION_PHASE_HIGHLIGHTED: true,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: true,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: false,
        NUMBER_OF_BIDDERS: false,
        WINNER: false,
        PENALIZED: false,
    },
    DELETED: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: false,
        AUCTION_PHASE_HIGHLIGHTED: true,
        ROUND: true,
        ROUND_TITLE: false,
        AT_AUCTION_SINCE: false,
        BIDDING_START: false,
        BIDDING_END: false,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: false,
        NUMBER_OF_BIDDERS: false,
        WINNER: false,
        PENALIZED: false,
    },
})

/**
 * The definition of the visibility of every piece of information shown on the auction detail's page. Determines
 * displayed information based on the auction round's state. Applies for all but the latest round.
 * Syntax: `LATEST_ROUND_INFO_VISIBILITY[<round's state>][AUCTION_ROUND_INFOS.<information key>]`, where `true` means
 * the specified information is displayed, `false` it isn't.
 */
export const OLDER_ROUND_INFO_VISIBILITY = Object.freeze({
    FINISHED_NOT_PAID: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: false,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: false,
        ROUND_TITLE: true,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: true,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: true,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: false,
        AUCTION_PRICE: true,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    FINISHED_NOT_TAKEN: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: false,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: false,
        ROUND_TITLE: true,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: false,
        PENDING_REGULAR_PAYMENT_BY: true,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: true,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: true,
        AUCTION_PHASE_USER_HIGHLIGHTED: false,
        CURRENT_PRICE: true,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: false,
        VARIABLE_SYMBOL: true,
        PENALTY_VARIABLE_SYMBOL: false,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: true,
        PENALIZED: false,
    },
    PENDING_PENALTY: {
        BUTTON_RESUME: false,
        BUTTON_STOP: false,
        AUCTION_PHASE_COMMON: false,
        AUCTION_PHASE_HIGHLIGHTED: false,
        ROUND: false,
        ROUND_TITLE: true,
        AT_AUCTION_SINCE: true,
        BIDDING_START: true,
        BIDDING_END: true,
        PENDING_REGULAR_PAYMENT_SINCE: false,
        PENDING_PENALTY_PAYMENT_SINCE: true,
        PENDING_REGULAR_PAYMENT_BY: false,
        PAID_SINCE: false,
        PENDING_REGISTRATION_BY: false,
        NOT_REGISTERED_SINCE: false,
        REGISTERED_SINCE: false,
        STOPPED_SINCE: false,
        AUCTION_PHASE_USER_COMMON: false,
        AUCTION_PHASE_USER_HIGHLIGHTED: true,
        CURRENT_PRICE: false,
        AUCTION_PRICE: false,
        PENALTY_AMOUNT: true,
        VARIABLE_SYMBOL: false,
        PENALTY_VARIABLE_SYMBOL: true,
        NUMBER_OF_BIDS: true,
        NUMBER_OF_BIDDERS: true,
        WINNER: false,
        PENALIZED: true,
    },
})
